==> flutter_bl_umpush-0.0.7.tar.gz: ios/Classes/FlutterBlUmpushPlugin.m <==
#import "FlutterBlUmpushPlugin.h"
#import  <UMCommon/UMCommon.h>  // 公共组件是所有友盟产品的基础组件，必选
#import  <UMPush/UMessage.h>  // Push组件
#import  <UserNotifications/UserNotifications.h>// Push组件必须的系统库
#import  <UMAnalytics/MobClick.h>
#import  <UMCommonLog/UMCommonLogHeaders.h>


#if defined(__IPHONE_10_0) && __IPHONE_OS_VERSION_MAX_ALLOWED >= __IPHONE_10_0


@interface FlutterBlUmpushPlugin () <UNUserNotificationCenterDelegate>

@end

#endif

@implementation FlutterBlUmpushPlugin{
    FlutterMethodChannel *_channel;
    NSDictionary *_launchNotification;
    BOOL _resumingFromBackground;
}


+ (void)registerWithRegistrar:(NSObject <FlutterPluginRegistrar> *)registrar {
    NSLog(@"umeng_push_plugin registerWithRegistrar registrar: %@", registrar);

    FlutterMethodChannel* channel =
    [FlutterMethodChannel methodChannelWithName:@"flutter_bl_umpush"
                                binaryMessenger:[registrar messenger]];
    FlutterBlUmpushPlugin* instance = [[FlutterBlUmpushPlugin alloc] initWithChannel:channel];
    [registrar addMethodCallDelegate:instance channel:channel];
    [registrar addApplicationDelegate:instance];
}

- (instancetype)initWithChannel:(FlutterMethodChannel *)channel {
    self = [super init];
    if (self) {
        _channel = channel;
        _resumingFromBackground = NO;
    }
    return self;
}


- (void)handleMethodCall:(FlutterMethodCall *)call result:(FlutterResult)result {
    NSLog(@"方法名称: %@", call.method);
    NSString *method = call.method;
    if ([@"setBadgeClear" isEqualToString:method]) {//清除角标
        result(@YES);
    }else if([@"setAutoAlert" isEqualToString:method]) {
        result(@YES);
    }else if([@"initWithAppkey" isEqualToString:method]) {//初始化
        [self initWithAppkey:call.arguments];
        result(@YES);
    }
    else if([@"addAlias" isEqualToString:method]) {//别名
        [self addAlias:call.arguments];
        result(@YES);
    }
    else if([@"addtags" isEqualToString:method]) {//标签
        [self addtags:call.arguments];
        result(@YES);
    }else if ([@"setScenarioType" isEqualToString:call.method]) {//启动统计
        [self setScenarioType];
        result(@YES);
    }
    else if ([@"umengEnterViewWithName" isEqualToString:call.method]) {//界面统计进入
        [self umengEnterViewWithName:call.arguments];
        result(@YES);
    }else if ([@"umengOutViewWithName" isEqualToString:call.method]) {//界面统计退出
        [self umengOutViewWithName:call.arguments];
        result(@YES);
    }else if ([@"umengEventCountWithId" isEqualToString:call.method]) {//事件统计
        [self umengEventCountWithId:call.arguments];
        result(@YES);
    }else if ([@"getPlatformVersion" isEqualToString:call.method]) {
        result([@"iOS " stringByAppendingString:[[UIDevice currentDevice] systemVersion]]);
    }else if ([@"initUMPushOptions" isEqualToString:call.method]){//推送初始化
        [self initUMPushOptions:call.arguments];
         result(@YES);
    }
    else {
        result(FlutterMethodNotImplemented);
    }

}

- (void)application:(UIApplication *)application
didRegisterForRemoteNotificationsWithDeviceToken:(NSData *)deviceToken
{
    if (![deviceToken isKindOfClass:[NSData class]]) return;

    [UMessage registerDeviceToken:deviceToken];

    NSLog(@"didRegisterForRemoteNotificationsWithDeviceToken success");

    NSLog(@"deviceToken————>>>%@",[[[[deviceToken description]
                                     stringByReplacingOccurrencesOfString: @"<"withString: @""]
                                    stringByReplacingOccurrencesOfString: @">"withString: @""]
                                   stringByReplacingOccurrencesOfString: @" "withString: @""]);


     NSString *(^getDeviceToken)(void) = ^() {
            if (@available(iOS 13.0, *)) {
                const unsigned char *dataBuffer = (const unsigned char *)deviceToken.bytes;
                NSMutableString *myToken  = [NSMutableString stringWithCapacity:(deviceToken.length * 2)];
                for (int i = 0; i < deviceToken.length; i++) {
                    [myToken appendFormat:@"%02x", dataBuffer[i]];
                }
                return (NSString *)[myToken copy];
            } else {
                NSCharacterSet *characterSet = [NSCharacterSet characterSetWithCharactersInString:@"<>"];
                NSString *myToken = [[deviceToken description] stringByTrimmingCharactersInSet:characterSet];
                return [myToken stringByReplacingOccurrencesOfString:@" " withString:@""];
            }
        };


    NSString *myToken = getDeviceToken();
    NSLog(@"%@", myToken);

    [_channel invokeMethod:@"callbackDeviceToken" arguments:myToken];
}



-(BOOL)application:(UIApplication *)application didFinishLaunchingWithOptions:(NSDictionary *)launchOptions{

    _launchNotification = launchOptions;
    [self performSelector:@selector(run:) withObject:nil afterDelay:3];

    return YES;
}

- (void)run:(id)sender{
    if(_launchNotification!=nil){
        NSDictionary *info = _launchNotification[@"UIApplicationLaunchOptionsRemoteNotificationKey"];
        [_channel invokeMethod:@"openNotification" arguments:info];
    }
}



//iOS10以下使用这两个方法接收通知
-(BOOL)application:(UIApplication *)application didReceiveRemoteNotification:(NSDictionary *)userInfo fetchCompletionHandler:(void (^)(UIBackgroundFetchResult))completionHandler
{
    [UMessage setAutoAlert:NO];
    if([[[UIDevice currentDevice] systemVersion]intValue] < 10){
        [UMessage didReceiveRemoteNotification:userInfo];
    }
     completionHandler(UIBackgroundFetchResultNewData);
    return YES;
}


//iOS10新增：处理前台收到通知的代理方法
-(void)userNotificationCenter:(UNUserNotificationCenter *)center willPresentNotification:(UNNotification *)notification withCompletionHandler:(void (^)(UNNotificationPresentationOptions))completionHandler API_AVAILABLE(ios(10.0)){
    NSDictionary * userInfo = notification.request.content.userInfo;
    if (@available(iOS 10.0, *)) {
        if([notification.request.trigger isKindOfClass:[UNPushNotificationTrigger class]]) {
            [UMessage setAutoAlert:NO];
            //应用处于前台时的远程推送接受
            //必须加这句代码
            [UMessage didReceiveRemoteNotification:userInfo];
//            [_channel invokeMethod:@"UMPush" arguments:userInfo];
        }else{
            //应用处于前台时的本地推送接受
        }
    } else {
        // Fallback on earlier versions
    }
    completionHandler(UNNotificationPresentationOptionSound|
                      UNNotificationPresentationOptionBadge|
                      UNNotificationPresentationOptionAlert);
}

//iOS10新增：处理后台点击通知的代理方法
-(void)userNotificationCenter:(UNUserNotificationCenter *)center didReceiveNotificationResponse:(UNNotificationResponse *)response withCompletionHandler:(void (^)(void))completionHandler API_AVAILABLE(ios(10.0)){
    NSDictionary * userInfo = response.notification.request.content.userInfo;
    if (@available(iOS 10.0, *)) {
        if([response.notification.request.trigger isKindOfClass:[UNPushNotificationTrigger class]]) {
            //应用处于后台时的远程推送接受
            //必须加这句代码
            [UMessage didReceiveRemoteNotification:userInfo];
            [_channel invokeMethod:@"openNotification" arguments:userInfo];
        }else{
            //应用处于后台时的本地推送接受
        }
    } else {
        // Fallback on earlier versions
    }
}

#pragma mark-统计

-(void)initWithAppkey:(NSDictionary*)dict{

    [UMConfigure setLogEnabled:YES];
    [UMCommonLogManager setUpUMCommonLogManager];
    [UMConfigure setLogEnabled:YES];
//    NSLog(@"友盟初始化");
    NSString *appKey = dict[@"appKey"];

    NSString *channel = dict[@"channel"];
    //配置友盟SDK产品并并统一初始化
    [UMConfigure initWithAppkey:appKey channel:channel];

    NSString *str =[UMConfigure deviceIDForIntegration];

    NSLog(@"token:%@",str);
}

//启动统计
-(void)setScenarioType{
     [MobClick setScenarioType:E_UM_NORMAL];
}

//页面统计 - 进入
- (void)umengEnterViewWithName:(NSString *)name{
    [MobClick beginLogPageView:name];
}

//页面统计 - 退出
- (void)umengOutViewWithName:(NSString *)name{
    [MobClick endLogPageView:name];
}

//计数事件统计
- (void)umengEventCountWithId:(NSString *)eventId{
    [MobClick event:eventId];
}



-(void)setBadgeClear:(BOOL)isClear{
    NSLog(@"友盟是否清除角标");
    //设置是否允许SDK自动清空角标
    [UMessage setBadgeClear:isClear];
}

//设置是否允许SDK当应用在前台运行收到Push时弹出Alert框
-(void)setAutoAlert:(BOOL)isAlert{
    NSLog(@"友盟是否弹框");
    [UMessage setAutoAlert:isAlert];
}


#pragma mark-友盟推送
-(void)initUMPushOptions:(NSDictionary*)dict{

    NSString *appKey = dict[@"appKey"];
    NSString *channel = dict[@"channel"];
    // Push组件基本功能配置
    UMessageRegisterEntity * entity = [[UMessageRegisterEntity alloc] init];
    //type是对推送的几个参数的选择，可以选择一个或者多个。默认是三个全部打开，即：声音，弹窗，角标
    entity.types = UMessageAuthorizationOptionBadge|UMessageAuthorizationOptionSound|UMessageAuthorizationOptionAlert;
    if (@available(iOS 10.0, *)) {
        [UNUserNotificationCenter currentNotificationCenter].delegate=self;
    } else {
        // Fallback on earlier versions
    }
    [UMessage registerForRemoteNotificationsWithLaunchOptions:_launchNotification Entity:entity completionHandler:^(BOOL granted, NSError * _Nullable error) {
        if (granted) {
        }else{
        }
    }];

    //设置是否允许SDK自动清空角标
//    [UMessage setBadgeClear:NO];
    //设置是否允许SDK当应用在前台运行收到Push时弹出Alert框
//    [UMessage setAutoAlert:NO];
}

#pragma mark-设置别名
-(void)addAlias:(NSString*)account{
    NSLog(@"友盟设置别名");
    //绑定别名
    [UMessage addAlias:account type:@"iOS" response:^(id  _Nonnull responseObject, NSError * _Nonnull error) {
    }];
//    //重置别名
//    [UMessage setAlias:@"test@umeng.com" type:@"UMENGTEST" response:^(id  _Nonnull responseObject, NSError * _Nonnull error) {
//    }];
//    //移除别名
//    [UMessage removeAlias:@"test@umeng.com" type:@"UMENGTEST" response:^(id  _Nonnull responseObject, NSError * _Nonnull error) {
//    }];
}

#pragma mark-设置标签
-(void)addtags:(NSString*)tag{
    NSLog(@"友盟设置标签");
    //添加标签
    [UMessage addTags:tag response:^(id  _Nonnull responseObject, NSInteger remain, NSError * _Nonnull error) {}];
}

#pragma mark 字典转化字符串
-(NSString*)dictionaryToJson:(NSDictionary *)dic{
    NSError *parseError = nil;
    NSData *jsonData = [NSJSONSerialization dataWithJSONObject:dic options:NSJSONWritingPrettyPrinted error:&parseError];
    return [[NSString alloc] initWithData:jsonData encoding:NSUTF8StringEncoding];
}

@end

==> flutter_bl_umpush-0.0.8.tar.gz: ios/Classes/FlutterBlUmpushPlugin.m <==
#import "FlutterBlUmpushPlugin.h"
#import  <UMCommon/UMCommon.h>  // 公共组件是所有友盟产品的基础组件，必选
#import  <UMPush/UMessage.h>  // Push组件
#import  <UserNotifications/UserNotifications.h>// Push组件必须的系统库
#import  <UMAnalytics/MobClick.h>
#import  <UMCommonLog/UMCommonLogHeaders.h>


#if defined(__IPHONE_10_0) && __IPHONE_OS_VERSION_MAX_ALLOWED >= __IPHONE_10_0


@interface FlutterBlUmpushPlugin () <UNUserNotificationCenterDelegate>

@end

#endif

@implementation FlutterBlUmpushPlugin{
    FlutterMethodChannel *_channel;
    NSDictionary *_launchNotification;
    BOOL _resumingFromBackground;
}


+ (void)registerWithRegistrar:(NSObject <FlutterPluginRegistrar> *)registrar {
    NSLog(@"umeng_push_plugin registerWithRegistrar registrar: %@", registrar);

    FlutterMethodChannel* channel =
    [FlutterMethodChannel methodChannelWithName:@"flutter_bl_umpush"
                                binaryMessenger:[registrar messenger]];
    FlutterBlUmpushPlugin* instance = [[FlutterBlUmpushPlugin alloc] initWithChannel:channel];
    [registrar addMethodCallDelegate:instance channel:channel];
    [registrar addApplicationDelegate:instance];
}

- (instancetype)initWithChannel:(FlutterMethodChannel *)channel {
    self = [super init];
    if (self) {
        _channel = channel;
        _resumingFromBackground = NO;
    }
    return self;
}


- (void)handleMethodCall:(FlutterMethodCall *)call result:(FlutterResult)result {
    NSLog(@"方法名称: %@", call.method);
    NSString *method = call.method;
    if ([@"setBadgeClear" isEqualToString:method]) {//清除角标
        result(@YES);
    }else if([@"setAutoAlert" isEqualToString:method]) {
        result(@YES);
    }else if([@"initWithAppkey" isEqualToString:method]) {//初始化
        [self initWithAppkey:call.arguments];
        result(@YES);
    }
    else if([@"addAlias" isEqualToString:method]) {//别名
        [self addAlias:call.arguments];
        result(@YES);
    }
    else if([@"addtags" isEqualToString:method]) {//标签
        [self addtags:call.arguments];
        result(@YES);
    }else if ([@"setScenarioType" isEqualToString:call.method]) {//启动统计
        [self setScenarioType];
        result(@YES);
    }
    else if ([@"umengEnterViewWithName" isEqualToString:call.method]) {//界面统计进入
        [self umengEnterViewWithName:call.arguments];
        result(@YES);
    }else if ([@"umengOutViewWithName" isEqualToString:call.method]) {//界面统计退出
        [self umengOutViewWithName:call.arguments];
        result(@YES);
    }else if ([@"umengEventCountWithId" isEqualToString:call.method]) {//事件统计
        [self umengEventCountWithId:call.arguments];
        result(@YES);
    }else if ([@"getPlatformVersion" isEqualToString:call.method]) {
        result([@"iOS " stringByAppendingString:[[UIDevice currentDevice] systemVersion]]);
    }else if ([@"initUMPushOptions" isEqualToString:call.method]){//推送初始化
        [self initUMPushOptions:call.arguments];
         result(@YES);
    }else if ([@"getStartUpPushInfo" isEqualToString:call.method]){
        NSDictionary *info = [self getStartUpPushInfo];
        result(info);
    }
    else {
        result(FlutterMethodNotImplemented);
    }

}

- (void)application:(UIApplication *)application
didRegisterForRemoteNotificationsWithDeviceToken:(NSData *)deviceToken
{
    if (![deviceToken isKindOfClass:[NSData class]]) return;

    [UMessage registerDeviceToken:deviceToken];

    NSLog(@"didRegisterForRemoteNotificationsWithDeviceToken success");

    NSLog(@"deviceToken————>>>%@",[[[[deviceToken description]
                                     stringByReplacingOccurrencesOfString: @"<"withString: @""]
                                    stringByReplacingOccurrencesOfString: @">"withString: @""]
                                   stringByReplacingOccurrencesOfString: @" "withString: @""]);


     NSString *(^getDeviceToken)(void) = ^() {
            if (@available(iOS 13.0, *)) {
                const unsigned char *dataBuffer = (const unsigned char *)deviceToken.bytes;
                NSMutableString *myToken  = [NSMutableString stringWithCapacity:(deviceToken.length * 2)];
                for (int i = 0; i < deviceToken.length; i++) {
                    [myToken appendFormat:@"%02x", dataBuffer[i]];
                }
                return (NSString *)[myToken copy];
            } else {
                NSCharacterSet *characterSet = [NSCharacterSet characterSetWithCharactersInString:@"<>"];
                NSString *myToken = [[deviceToken description] stringByTrimmingCharactersInSet:characterSet];
                return [myToken stringByReplacingOccurrencesOfString:@" " withString:@""];
            }
        };


    NSString *myToken = getDeviceToken();
    NSLog(@"%@", myToken);

    [_channel invokeMethod:@"callbackDeviceToken" arguments:myToken];
}



-(BOOL)application:(UIApplication *)application didFinishLaunchingWithOptions:(NSDictionary *)launchOptions{

    _launchNotification = launchOptions;
//    [self performSelector:@selector(run:) withObject:nil afterDelay:3];

    return YES;
}

- (void)run:(id)sender{
    if(_launchNotification!=nil){
        NSDictionary *info = _launchNotification[@"UIApplicationLaunchOptionsRemoteNotificationKey"];
        [_channel invokeMethod:@"openNotification" arguments:info];
    }
}



//iOS10以下使用这两个方法接收通知
-(BOOL)application:(UIApplication *)application didReceiveRemoteNotification:(NSDictionary *)userInfo fetchCompletionHandler:(void (^)(UIBackgroundFetchResult))completionHandler
{
    [UMessage setAutoAlert:NO];
    if([[[UIDevice currentDevice] systemVersion]intValue] < 10){
        [UMessage didReceiveRemoteNotification:userInfo];
    }
     completionHandler(UIBackgroundFetchResultNewData);
    return YES;
}


//iOS10新增：处理前台收到通知的代理方法
-(void)userNotificationCenter:(UNUserNotificationCenter *)center willPresentNotification:(UNNotification *)notification withCompletionHandler:(void (^)(UNNotificationPresentationOptions))completionHandler API_AVAILABLE(ios(10.0)){
    NSDictionary * userInfo = notification.request.content.userInfo;
    if (@available(iOS 10.0, *)) {
        if([notification.request.trigger isKindOfClass:[UNPushNotificationTrigger class]]) {
            [UMessage setAutoAlert:NO];
            //应用处于前台时的远程推送接受
            //必须加这句代码
            [UMessage didReceiveRemoteNotification:userInfo];
//            [_channel invokeMethod:@"UMPush" arguments:userInfo];
        }else{
            //应用处于前台时的本地推送接受
        }
    } else {
        // Fallback on earlier versions
    }
    completionHandler(UNNotificationPresentationOptionSound|
                      UNNotificationPresentationOptionBadge|
                      UNNotificationPresentationOptionAlert);
}

//iOS10新增：处理后台点击通知的代理方法
-(void)userNotificationCenter:(UNUserNotificationCenter *)center didReceiveNotificationResponse:(UNNotificationResponse *)response withCompletionHandler:(void (^)(void))completionHandler API_AVAILABLE(ios(10.0)){
    NSDictionary * userInfo = response.notification.request.content.userInfo;
    if (@available(iOS 10.0, *)) {
        if([response.notification.request.trigger isKindOfClass:[UNPushNotificationTrigger class]]) {
            //应用处于后台时的远程推送接受
            //必须加这句代码
            [UMessage didReceiveRemoteNotification:userInfo];
            [_channel invokeMethod:@"openNotification" arguments:userInfo];
        }else{
            //应用处于后台时的本地推送接受
        }
    } else {
        // Fallback on earlier versions
    }
}

#pragma mark-统计

-(void)initWithAppkey:(NSDictionary*)dict{

    [UMConfigure setLogEnabled:YES];
    [UMCommonLogManager setUpUMCommonLogManager];
    [UMConfigure setLogEnabled:YES];
//    NSLog(@"友盟初始化");
    NSString *appKey = dict[@"appKey"];

    NSString *channel = dict[@"channel"];
    //配置友盟SDK产品并并统一初始化
    [UMConfigure initWithAppkey:appKey channel:channel];

    NSString *str =[UMConfigure deviceIDForIntegration];

    NSLog(@"token:%@",str);
}

//启动统计
-(void)setScenarioType{
     [MobClick setScenarioType:E_UM_NORMAL];
}

//页面统计 - 进入
- (void)umengEnterViewWithName:(NSString *)name{
    [MobClick beginLogPageView:name];
}

//页面统计 - 退出
- (void)umengOutViewWithName:(NSString *)name{
    [MobClick endLogPageView:name];
}

//计数事件统计
- (void)umengEventCountWithId:(NSString *)eventId{
    [MobClick event:eventId];
}



-(void)setBadgeClear:(BOOL)isClear{
    NSLog(@"友盟是否清除角标");
    //设置是否允许SDK自动清空角标
    [UMessage setBadgeClear:isClear];
}

//设置是否允许SDK当应用在前台运行收到Push时弹出Alert框
-(void)setAutoAlert:(BOOL)isAlert{
    NSLog(@"友盟是否弹框");
    [UMessage setAutoAlert:isAlert];
}


#pragma mark-友盟推送
-(void)initUMPushOptions:(NSDictionary*)dict{

    NSString *appKey = dict[@"appKey"];
    NSString *channel = dict[@"channel"];
    // Push组件基本功能配置
    UMessageRegisterEntity * entity = [[UMessageRegisterEntity alloc] init];
    //type是对推送的几个参数的选择，可以选择一个或者多个。默认是三个全部打开，即：声音，弹窗，角标
    entity.types = UMessageAuthorizationOptionBadge|UMessageAuthorizationOptionSound|UMessageAuthorizationOptionAlert;
    if (@available(iOS 10.0, *)) {
        [UNUserNotificationCenter currentNotificationCenter].delegate=self;
    } else {
        // Fallback on earlier versions
    }
    [UMessage registerForRemoteNotificationsWithLaunchOptions:_launchNotification Entity:entity completionHandler:^(BOOL granted, NSError * _Nullable error) {
        if (granted) {
        }else{
        }
    }];

    //设置是否允许SDK自动清空角标
//    [UMessage setBadgeClear:NO];
    //设置是否允许SDK当应用在前台运行收到Push时弹出Alert框
//    [UMessage setAutoAlert:NO];
}

#pragma mark-设置别名
-(void)addAlias:(NSString*)account{
    NSLog(@"友盟设置别名");
    //绑定别名
    [UMessage addAlias:account type:@"iOS" response:^(id  _Nonnull responseObject, NSError * _Nonnull error) {
    }];
//    //重置别名
//    [UMessage setAlias:@"test@umeng.com" type:@"UMENGTEST" response:^(id  _Nonnull responseObject, NSError * _Nonnull error) {
//    }];
//    //移除别名
//    [UMessage removeAlias:@"test@umeng.com" type:@"UMENGTEST" response:^(id  _Nonnull responseObject, NSError * _Nonnull error) {
//    }];
}

#pragma mark-设置标签
-(void)addtags:(NSString*)tag{
    NSLog(@"友盟设置标签");
    //添加标签
    [UMessage addTags:tag response:^(id  _Nonnull responseObject, NSInteger remain, NSError * _Nonnull error) {}];
}


-(NSDictionary*)getStartUpPushInfo{
     NSDictionary *info = _launchNotification[@"UIApplicationLaunchOptionsRemoteNotificationKey"];
    if (info) {
        _launchNotification = nil;
        return info;
    }else{
        return @{};
    }
}

#pragma mark 字典转化字符串
-(NSString*)dictionaryToJson:(NSDictionary *)dic{
    NSError *parseError = nil;
    NSData *jsonData = [NSJSONSerialization dataWithJSONObject:dic options:NSJSONWritingPrettyPrinted error:&parseError];
    return [[NSString alloc] initWithData:jsonData encoding:NSUTF8StringEncoding];
}




@end
